@@ -20,7 +20,7 @@ class Ant():
         self.max_step = max_step    # 蚂蚁最大行动力
         self.pher_imp = pher_imp    # 信息素重要性系数
         self.dis_imp = dis_imp      # 距离重要性系数
-        self.destination = [19,19]  # 默认的终点节点
+        self.destination = [19,19]  # 默认的终点节点(在run方法中会重新定义该值)
         self.successful = True      #标志蚂蚁是否成功抵达终点
         self.record_way = [[0,0]]   #路径节点信息记录
         
@@ -110,7 +110,7 @@ class Ant():
 
 
 class ACO():
-    def __init__(self,max_iter = 100,pher_imp = 1,dis_imp = 10,evaporate = 0.7,pher_init = 8) -> None:
+    def __init__(self,max_iter = 100,ant_num = 50,pher_imp = 1,dis_imp = 10,evaporate = 0.7,pher_init = 8) -> None:
         '''
             Params:
             --------
@@ -121,7 +121,7 @@ class ACO():
         '''
         #Step 0: 参数定义及赋值
         self.max_iter = max_iter       #最大迭代次数
-        self.ant_num  = 50         #蚂蚁数量
+        self.ant_num  = ant_num        #蚂蚁数量
         self.ant_gener_pher = 1    #每只蚂蚁携带的最大信息素总量
         self.pher_init = pher_init #初始信息素浓度
         self.ant_params = {        #生成蚂蚁时所需的参数
@@ -952,7 +952,7 @@ class ShanGeTu():
         self.draw_barrier()                    #画障碍物方格，跟上一步共同组合成完整的背景图片
         #self.draw_way(way_data=way_data)
         #self.save()                            #保存起来
-        
+    @classmethod   
     def backgroud(self):
         '''
             Function:
@@ -992,7 +992,7 @@ class ShanGeTu():
                 py.draw.line(backgroud,[0,0,0],[i*(self.cell_size+self.line_size),0],[i*(self.cell_size+self.line_size),pic_size])
                 py.draw.line(backgroud,[0,0,0],[0,i*(self.cell_size+self.line_size)],[pic_size,i*(self.cell_size+self.line_size)])
             return backgroud
-
+    @classmethod
     def load_map(self,map_path,reverse = False):
         '''
         Function:
@@ -1014,7 +1014,7 @@ class ShanGeTu():
         if reverse == True:
             self.map_data.reverse()
         self.grid_size = len(self.map_data[0])
-
+    @classmethod
     def draw_barrier(self):
         for i in range(len(self.map_data[0])):
             for j in range(len(self.map_data[0])):
@@ -1079,7 +1079,7 @@ class ShanGeTu():
             if  reverse == True:
                 self.pic_backgroud = flip(self.pic_backgroud,False,True)
             py.image.save(self.pic_backgroud,filename)
-
+    @classmethod
     def seek_corner_point(self,way_data = [1,2,3,4]):
         '''
             Function:
@@ -1115,7 +1115,7 @@ class ShanGeTu():
         print(special_pot_list)
         print(special_pot_key_list)
         return special_pot_list, special_pot_key_list
-
+    @classmethod
     def is_near_obstacle(self,point_a,point_b):
         '''
             Function:
@@ -1159,7 +1159,7 @@ class ShanGeTu():
                     return True
                 else:
                     return False
-            
+    @classmethod            
     def calc_abs_x_y(self,point_data = 0):
         '''
             Function:
@@ -1247,7 +1247,7 @@ class ShanGeTu():
             py.draw.line(self.pic_shangetu,[255,150,50],[abs_xy_list[i][0],self.backgroud_size-abs_xy_list[i][1]],[abs_xy_list[i+1][0],self.backgroud_size-abs_xy_list[i+1][1]],3)
 
         #self.save('栅格图优化.jpg')
-        
+    @classmethod        
     def trigon_opt(self,pot_1,pot_2,pot_3,key_list):
         '''
             Function:
@@ -1275,7 +1275,7 @@ class ShanGeTu():
 
         else:
             return None
-       
+    @classmethod       
     def is_accross_barrier(self,pot_1 ,pot_2):
         '''
             Function:
@@ -1311,7 +1311,7 @@ class ShanGeTu():
             #else:
             #    print('判断节点:',self.grid_size-1-y_1,x_1,'结果为可通行')
         return [False,[]]                                #100个点都判断完了，返回False
-
+    @classmethod
     def deep_opt(self,pot_1,pot_2,pot_3):
         '''
         function:
@@ -1362,7 +1362,7 @@ class ShanGeTu():
                 pass
                 #print('继续...')
         #self.save()
-    
+    @classmethod    
     def seek_shortest_vertice(self,grid,pot_1,pot_2,pot_3):
         # Step 1: 先找到四个顶点坐标
         x = grid[0]
@@ -1387,6 +1387,7 @@ class ShanGeTu():
                 key = k
                 yuzhi = s
         return vertices[key]
+    @classmethod
     def calc_way_lenght(self):
         self.way_lenght = 0
         for i in range(len(self.final_opt_way)-1):
